@@ -27,10 +27,10 @@ program test
   end do
   close(unit=11,status='keep')
 
-  call Reg_Line( x, y, slope, intercept )
-  call Cor_Coe( x, y, cc )
-  call Anomaly_1d( x, xa )
-  call Anomaly_1d( y, ya )
+  call Reg_Line( nx, x, y, slope, intercept )
+  call Cor_Coe( nx, x, y, cc )
+  call Anomaly_1d( nx, x, xa )
+  call Anomaly_1d( nx, y, ya )
 
   open(unit=11,file='result.dat',status='unknown')
   do i=1,nx
