@@ -12,9 +12,6 @@ contains
 
 subroutine Rich_horizon( za, pta, ptg, va, qva, qvs, Ri )
 ! Х륯㡼ɥ׻롼
-  use Phys_Const
-  use Thermo_Function
-  use Thermo_Advanced_Function
   implicit none
   real, intent(in) :: za  ! 㡼ɥ׻ [m]
   real, intent(in), dimension(:,:) :: pta  ! za Ǥβ [K]
@@ -45,8 +42,6 @@ end subroutine
 
 subroutine Louis_horizon( z, z0m, richard, Lo )
 ! Louis(1980) ƤƤ絤԰٤θХ륯׻ؿ
-  use Thermo_Const
-  use Thermo_Advanced_Function
   implicit none
   real, intent(in) :: z  ! cm  [m]
   real, intent(in), dimension(:,:) :: z0m  ! ǥǷ׻ٹ [m]
@@ -75,8 +70,6 @@ end subroutine
 
 subroutine cm_horizon( z, z0m, coem, richard )
 ! ư̤˴ؤХ륯׻롼
-  use Thermo_Const
-  use Thermo_Advanced_Function
   implicit none
   real, intent(in) :: z  ! cm  [m]
   real, intent(in), dimension(:,:) :: z0m  ! ǥǷ׻ٹ [m]
@@ -115,7 +108,6 @@ end subroutine
 
 subroutine ust_horizon( cm, va, velst )
 ! ໤® u_* ׻롼
-  use Thermo_Advanced_Function
   implicit none
   real, intent(in), dimension(:,:) :: cm  !  za ǤΥХ륯
   real, intent(in), dimension(size(cm,1),size(cm,2)) :: va  !  za Ǥοʿ [m/s]
