@@ -399,6 +399,50 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
+!-- 餷Ф餯Ѵ -----------------
+
+real function rhoT_2_P( rho, T )
+! 絤ξ, ̩٤Ȳ٤ͿƵ.
+  implicit none
+  real, intent(in) :: rho  ! 絤̩ [kg/m^3]
+  real, intent(in) :: T    ! 絤β [K]
+
+  rhoT_2_P=rho*Rd*T
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
+real function rhoP_2_T( rho, P )
+! 絤ξ, ̩٤ȵͿƲ٤.
+  implicit none
+  real, intent(in) :: rho  ! 絤̩ [kg/m^3]
+  real, intent(in) :: P    ! 絤ΰ [Pa]
+
+  rhoP_2_T=P/(Rd*rho)
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
+real function TP_2_rho( T, P )
+! 絤ξ, ٤ȵͿ̩٤.
+  implicit none
+  real, intent(in) :: T    ! 絤β [K]
+  real, intent(in) :: P    ! 絤ΰ [Pa]
+
+  TP_2_rho=p/(Rd*T)
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
 real function get_gamma_d()  ! ǮΨƤִؿ(δؿɬפ)
   implicit none
 
