@@ -131,9 +131,9 @@ subroutine tangent_mean_vec( charc, x, y, xc, yc, u1, u2, r, theta, v )
   real, intent(in) :: theta(:)  ! ʿѲȤκɸ [rad].
   real, intent(inout) :: v(size(r))  ! ʿѲ u .
   integer :: i, j, k, nx, ny, nr, nt
-  real :: work1(size(r),size(theta)), work2(size(r),size(theta)), work3(size(r),size(theta))
-  real :: posx(size(r),size(theta)), posy(size(r),size(theta)), posz(size(r),size(theta))
-  real :: vecx(size(r),size(theta)), vecy(size(r),size(theta)), vecz(size(r),size(theta))
+  real :: work1(size(r),size(theta),1), work2(size(r),size(theta),1), work3(size(r),size(theta),1)
+  real :: posx(size(r),size(theta),1), posy(size(r),size(theta),1), posz(size(r),size(theta),1)
+  real :: vecx(size(r),size(theta),1), vecy(size(r),size(theta),1), vecz(size(r),size(theta),1)
   real :: abpos(size(r),size(theta))
   real :: point(size(r),size(theta),2)
   integer :: ip(size(r),size(theta),2)
@@ -197,12 +197,12 @@ subroutine tangent_mean_vec( charc, x, y, xc, yc, u1, u2, r, theta, v )
         tmpz(2,2)=u1(ip(i,j,1)+1,ip(i,j,2)+1)
         inter(1)=point(i,j,1)
         inter(2)=point(i,j,2)
-        call interpolation_2d( tmpx, tmpy, tmpz, inter, work1(i,j) )
+        call interpolation_2d( tmpx, tmpy, tmpz, inter, work1(i,j,1) )
         tmpz(1,1)=u2(ip(i,j,1),ip(i,j,2))
         tmpz(2,1)=u2(ip(i,j,1)+1,ip(i,j,2))
         tmpz(1,2)=u2(ip(i,j,1),ip(i,j,2)+1)
         tmpz(2,2)=u2(ip(i,j,1)+1,ip(i,j,2)+1)
-        call interpolation_2d( tmpx, tmpy, tmpz, inter, work2(i,j) )
+        call interpolation_2d( tmpx, tmpy, tmpz, inter, work2(i,j,1) )
      end do
   end do
 
@@ -210,18 +210,18 @@ subroutine tangent_mean_vec( charc, x, y, xc, yc, u1, u2, r, theta, v )
 !--    ΰ֥٥ȥȤγѤ׻
   do j=1,nt
      do i=1,nr
-        work3(i,j)=0.0
-        posx(i,j)=point(i,j,1)-xc
-        posy(i,j)=point(i,j,2)-yc
-        posz(i,j)=0.0
+        work3(i,j,1)=0.0
+        posx(i,j,1)=point(i,j,1)-xc
+        posy(i,j,1)=point(i,j,2)-yc
+        posz(i,j,1)=0.0
      end do
   end do
 
   select case (charc)
   case ('vector')
-     call vec_prod( nr, nt, 1, posx, posy, posz, work1, work2, work3, vecx, vecy, vecz )
+     call vec_prod( posx, posy, posz, work1, work2, work3, vecx, vecy, vecz )
   case ('scalar')
-     call dot_prod( nr, nt, 1, posx, posy, posz, work1, work2, work3, vecz )
+     call dot_prod( posx, posy, posz, work1, work2, work3, vecz )
   case default
      write(*,*) "error : bad character. select 'vector', or 'scalar'."
      stop
@@ -229,18 +229,18 @@ subroutine tangent_mean_vec( charc, x, y, xc, yc, u1, u2, r, theta, v )
 
 !-- 3. ٥ȥγʬΤ, z ʬˤĤ (2 ʿ̥٥ȥƱΤγ)
 !--    ֥٥ȥͤǳ. -> ®ʬޤͤ.
-  call abst( nr, nt, 1, posx, posy, posz, abpos )
+  call abst( posx, posy, posz, abpos )
 
   do j=1,nt
      do i=2,nr   
-        vecz(i,j)=vecz(i,j)/abpos(i,j)
+        vecz(i,j,1)=vecz(i,j,1)/abpos(i,j)
      end do
   end do
 
 
 !-- (4) ---
   do i=2,nr
-     call Mean_1d( nt, vecz(i,:), v(i) )
+     call Mean_1d( nt, vecz(i,:,1), v(i) )
   end do
   v(1)=0.0
 
